@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,9 +21,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: GEditTB.c,v 1.4 1999/05/03 17:17:49 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: GEditTB.c,v 1.5 2000/03/16 20:08:48 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: GEditTB.c,v 1.4 1999/05/03 17:17:49 mleisher Exp $";
+static char rcsid[] = "$Id: GEditTB.c,v 1.5 2000/03/16 20:08:48 mleisher Exp $";
 #endif
 #endif
 
@@ -2066,7 +2065,7 @@ Cardinal *num_params;
         cb.reason = XmuttGLYPHEDIT_CONTEXT_HELP;
         cb.event = event;
         if (b > _GETB_GLYPH_IMAGE) {
-            sprintf(cbuf, "Color %d", b - (_GETB_GLYPH_IMAGE + 1));
+            sprintf(cbuf, "Color %d", b - _GETB_GLYPH_IMAGE);
             cb.help = cbuf;
         } else
           cb.help = bp[b].help;
