@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -24,12 +23,14 @@
 #define _h_bdf
 
 /*
- * $Id: bdf.h,v 1.15 1999/10/23 13:43:36 mleisher Exp $
+ * $Id: bdf.h,v 1.16 2000/03/16 20:08:51 mleisher Exp $
  */
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifndef __digital__
 #include <unistd.h>
+#endif
 #include <string.h>
 
 #ifdef HAVE_XLIB
@@ -39,7 +40,8 @@
 #endif /* HAVE_XLIB */
 
 #ifdef HAVE_FREETYPE
-#include "freetype.h"
+#include <freetype.h>
+#include <extend/ftxsbit.h>
 #endif /* HAVE_FREETYPE */
 
 #ifdef __cplusplus
@@ -159,6 +161,14 @@ typedef struct {
     short flags;        /* Booleans and other non-numeric values.       */
 } bdf_sbit_t;
 
+/**************************************************************************
+ *
+ * BDF opaque undo information types.
+ *
+ **************************************************************************/
+
+typedef struct _bdf_undo_t *bdf_undo_t;
+
 /**************************************************************************
  *
  * BDF font metric and glyph types.
@@ -271,6 +281,10 @@ typedef struct {
     bdf_sbit_t *sbits;          /* Associcated SBIT metrics.             */
     unsigned long sbits_used;   /* Number of SBIT metrics entries.       */
     unsigned long sbits_size;   /* Amount of entries allocated.          */
+
+    bdf_undo_t *undo_stack;     /* Record of undoable operations.        */
+    unsigned long undo_used;    /* Amount of undo stack used.            */
+    unsigned long undo_size;    /* Amount of undo stack allocated.       */
 } bdf_font_t;
 
 /**************************************************************************
@@ -648,7 +662,7 @@ extern int bdf_shear_glyphs __((bdf_font_t *font, short degrees,
 
 extern int bdf_embolden_glyphs __((bdf_font_t *font, long start, long end,
                                    bdf_callback_t callback, void *data,
-                                   int unencoded));
+                                   int unencoded, int *resize));
 
 extern int bdf_little_endian __((void));
 
