@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,9 +21,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: bdffnt.c,v 1.6 1999/10/23 13:43:36 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: bdffnt.c,v 1.7 2000/03/16 20:08:51 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: bdffnt.c,v 1.6 1999/10/23 13:43:36 mleisher Exp $";
+static char rcsid[] = "$Id: bdffnt.c,v 1.7 2000/03/16 20:08:51 mleisher Exp $";
 #endif
 #endif
 
@@ -295,10 +294,10 @@ unsigned long *lp, n;
 
 static unsigned short
 #ifdef __STDC__
-_bdffnt_get_short(char *field)
+_bdffnt_get_short(unsigned char *field)
 #else
 _bdffnt_get_short(field)
-char *field;
+unsigned char *field;
 #endif
 {
     int a = 0, b = 1;
@@ -313,10 +312,10 @@ char *field;
 
 static unsigned long
 #ifdef __STDC__
-_bdffnt_get_long(char *field)
+_bdffnt_get_long(unsigned char *field)
 #else
 _bdffnt_get_long(field)
-char *field;
+unsigned char *field;
 #endif
 {
     int a = 0, b = 1, c = 2, d = 3;
