@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -28,9 +27,9 @@
 
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: bdfttf.c,v 1.5 1999/05/03 17:17:54 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: bdfttf.c,v 1.6 2000/03/16 20:08:52 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: bdfttf.c,v 1.5 1999/05/03 17:17:54 mleisher Exp $";
+static char rcsid[] = "$Id: bdfttf.c,v 1.6 2000/03/16 20:08:52 mleisher Exp $";
 #endif
 #endif
 
@@ -273,7 +272,7 @@ void *data;
 bdf_font_t *fp;
 #endif
 {
-    int ismono, load_flags;
+    int ismono, load_flags, have_strike;
     long awidth, code, idx;
     short maxrb, maxlb, minlb, minx, maxx, miny, maxy;
     short xoff, yoff, x_off, y_off, maxas, maxds;
@@ -285,9 +284,11 @@ bdf_font_t *fp;
     bdf_property_t prop;
     TT_Instance instance;
     TT_Glyph glyph;
-    TT_Glyph_Metrics metrics;
+    TT_Big_Glyph_Metrics metrics, *mp;
     TT_Instance_Metrics imetrics;
-    TT_Raster_Map raster;
+    TT_Raster_Map raster, *rp;
+    TT_SBit_Image *sbit;
+    TT_SBit_Strike strike;
 
     /*
      * Create a new instance.
@@ -300,13 +301,17 @@ bdf_font_t *fp;
      */
     (void) TT_Set_Instance_Resolutions(instance, opts->resolution_x,
                                        opts->resolution_y);
-    (void) TT_Set_Instance_CharSize(instance, opts->point_size << 6);
+    (void) TT_Set_Instance_PointSize(instance, opts->point_size);
     (void) TT_Get_Instance_Metrics(instance, &imetrics);
 
     /*
-     * Create a new glyph container.
+     * Check to see if this font has embedded bitmaps.
      */
-    if (TT_New_Glyph(face, &glyph)) {
+    have_strike = (TT_Get_SBit_Strike(face, instance, &strike)) ? 0 : 1;
+
+    if (have_strike)
+      (void) TT_New_SBit_Image(&sbit);
+    else if (TT_New_Glyph(face, &glyph)) {
         (void) TT_Done_Instance(instance);
         return 0;
     }
@@ -352,12 +357,7 @@ bdf_font_t *fp;
     maxx = (maxx - minx) + 1;
     maxy = (maxy - miny) + 1;
 
-    raster.flow = TT_Flow_Up;
-    raster.width = maxx;
-    raster.rows = maxy;
-    raster.cols = (maxx + 7) >> 3;
-    raster.size = raster.cols * raster.rows;
-    raster.bitmap = (void *) malloc(raster.size);
+    raster.size = 0;
 
     for (code = fp->glyphs_used = 0; code < 0xffff; code++) {
         if (nocmap) {
@@ -370,28 +370,52 @@ bdf_font_t *fp;
         } else
           idx = TT_Char_Index(cmap, code);
 
-        if (idx <= 0 || TT_Load_Glyph(instance, glyph, idx, load_flags))
+        if (idx <= 0 ||
+            (have_strike && TT_Load_Glyph_Bitmap(face, instance, idx, sbit)) ||
+            (!have_strike && TT_Load_Glyph(instance, glyph, idx, load_flags)))
           continue;
 
-        (void) TT_Get_Glyph_Metrics(glyph, &metrics);
+        if (have_strike) {
+            /*
+             * Set the pointers to the raster and metrics structures.
+             */
+            rp = &sbit->map;
+            mp = &sbit->metrics;
+            xoff = (63 - mp->bbox.xMin) & -64;
+            yoff = (63 - mp->bbox.yMin) & -64;
+        } else {
+            if (raster.size == 0) {
+                raster.flow = TT_Flow_Down;
+                raster.width = maxx;
+                raster.rows = maxy;
+                raster.cols = (maxx + 7) >> 3;
+                raster.size = raster.cols * raster.rows;
+                raster.bitmap = (void *) malloc(raster.size);
+            }
 
-        /*
-         * Clear the raster bitmap.
-         */
-        (void) memset((char *) raster.bitmap, 0, raster.size);
+            (void) TT_Get_Glyph_Big_Metrics(glyph, &metrics);
 
-        /*
-         * Grid fit to determine the x and y offsets that will force the
-         * bitmap to fit into the storage provided.
-         */
-        xoff = (63 - metrics.bbox.xMin) & -64;
-        yoff = (63 - metrics.bbox.yMin) & -64;
+            /*
+             * Clear the raster bitmap.
+             */
+            (void) memset((char *) raster.bitmap, 0, raster.size);
 
-        /*
-         * If the bitmap cannot be generated, simply continue.
-         */
-        if (TT_Get_Glyph_Bitmap(glyph, &raster, xoff, yoff))
-          continue;
+            /*
+             * Grid fit to determine the x and y offsets that will force the
+             * bitmap to fit into the storage provided.
+             */
+            xoff = (63 - metrics.bbox.xMin) & -64;
+            yoff = (63 - metrics.bbox.yMin) & -64;
+
+            /*
+             * If the bitmap cannot be generated, simply continue.
+             */
+            if (TT_Get_Glyph_Bitmap(glyph, &raster, xoff, yoff))
+              continue;
+
+            rp = &raster;
+            mp = &metrics;
+        }
 
         /*
          * Increase the amount of storage by 128 every time.
@@ -410,7 +434,7 @@ bdf_font_t *fp;
          */
         gp = fp->glyphs + fp->glyphs_used++;
         gp->encoding = code;
-        gp->dwidth = metrics.advance >> 6;
+        gp->dwidth = mp->horiAdvance >> 6;
         gp->swidth = (unsigned short)
             (((double) gp->dwidth) * 72000.0) / swscale;
 
@@ -418,21 +442,17 @@ bdf_font_t *fp;
          * Determine the actual bounding box of the glyph bitmap.  Do not
          * forget that the glyph is rendered upside down!
          */
-        sx = ey = 0xffff;
-        sy = ex = 0;
-        bmap = (unsigned char *) raster.bitmap;
-        for (miny = 0; miny < raster.rows; miny++) {
-            for (minx = 0; minx < raster.width; minx++) {
-                if (bmap[(miny * raster.cols) + (minx >> 3)] &
+        sx = sy = 0xffff;
+        ex = ey = 0;
+        bmap = (unsigned char *) rp->bitmap;
+        for (miny = 0; miny < rp->rows; miny++) {
+            for (minx = 0; minx < rp->width; minx++) {
+                if (bmap[(miny * rp->cols) + (minx >> 3)] &
                     (0x80 >> (minx & 7))) {
-                    if (minx < sx)
-                      sx = minx;
-                    if (minx > ex)
-                      ex = minx;
-                    if (miny > sy)
-                      sy = miny;
-                    if (miny < ey)
-                      ey = miny;
+                    if (minx < sx) sx = minx;
+                    if (minx > ex) ex = minx;
+                    if (miny < sy) sy = miny;
+                    if (miny > ey) ey = miny;
                 }
             }
         }
@@ -441,8 +461,15 @@ bdf_font_t *fp;
          * If the glyph is actually an empty bitmap, set the size to 0 all
          * around.
          */
-        if (sx == 0xffff && ey == 0xffff && sy == 0 && ex == 0)
+        if (sx == 0xffff && sy == 0xffff && ex == 0 && ey == 0)
           sx = ex = sy = ey = 0;
+        else {
+            /*
+             * Adjust the end points.
+             */
+            ex++;
+            ey++;
+        }
 
         /*
          * Test to see if the font is going to be monowidth or not by
@@ -454,10 +481,10 @@ bdf_font_t *fp;
         /*
          * Set the initial metrics.
          */
-        wd = (ex - sx) + 1;
-        ht = (sy - ey) + 1;
+        wd = ex - sx;
+        ht = ey - sy;
         x_off = sx - (xoff >> 6);
-        y_off = ey - (yoff >> 6);
+        y_off = -(yoff >> 6);
 
         /*
          * Adjust the overall bounding box.
@@ -494,10 +521,10 @@ bdf_font_t *fp;
         /*
          * Shift the bits into the glyph bitmap.
          */
-        for (maxy = 0, miny = sy; miny >= ey; miny--, maxy++) {
-            for (maxx = 0, minx = sx; minx <= ex; minx++, maxx++) {
-                if (bmap[(miny * raster.cols) + (minx >> 3)] &
-                    (0x80 >> (minx & 7)))
+        for (maxy = 0, miny = sy; miny < ey; miny++, maxy++) {
+            for (maxx = 0, minx = sx; minx < ex; minx++, maxx++) {
+                if (bmap[(miny * rp->cols) + ((minx - sx) >> 3)] &
+                    (0x80 >> ((minx - sx) & 7)))
                   gp->bitmap[(maxy * bpr) + (maxx >> 3)] |=
                       (0x80 >> (maxx & 7));
             }
@@ -517,8 +544,13 @@ bdf_font_t *fp;
     /*
      * Do cleanup.
      */
-    TT_Done_Glyph(glyph);
+    if (have_strike)
+      TT_Done_SBit_Image(sbit);
+    else
+      TT_Done_Glyph(glyph);
+
     TT_Done_Instance(instance);
+
     if (raster.size > 0)
       free((char *) raster.bitmap);
 
@@ -713,7 +745,7 @@ bdf_font_t **font;
      * If the number of glyphs loaded is less than the reported number of
      * glyphs, force a callback if one was provided.
      */
-    if (fp->glyphs_used < properties->num_Glyphs) {
+    if (callback != 0 && fp->glyphs_used < properties->num_Glyphs) {
         cb.reason = BDF_LOADING;
         cb.total = cb.current = properties->num_Glyphs;
         (*callback)(&cb, data);
