@@ -1,13 +1,12 @@
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: hbf.c,v 1.2 1999/05/03 17:17:56 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: hbf.c,v 1.3 2000/03/16 20:08:54 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: hbf.c,v 1.2 1999/05/03 17:17:56 mleisher Exp $";
+static char rcsid[] = "$Id: hbf.c,v 1.3 2000/03/16 20:08:54 mleisher Exp $";
 #endif
 #endif
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * - You can use this code for any purpose and without fee, except that
  *   you may distribute only verbatim copies of it.  Please send me any
@@ -361,7 +360,7 @@ reg	const	char	*sp;
 		lp++;
 		sp++;
 	}
-	return (*lp == '\0' || isspace(*lp)) && *sp == '\0';
+	return (*lp == '\0' || isspace((int) *lp)) && *sp == '\0';
 }
 
 #ifdef NO_STRDUP
@@ -393,12 +392,12 @@ reg	char	*tp;
 	prop = NEW(PROPERTY);
 
 	tp = tmp;
-	while (*lp != '\0' && ! isspace(*lp))
+	while (*lp != '\0' && ! isspace((int) *lp))
 		*tp++ = *lp++;
 	*tp = '\0';
 	prop->prop_name = strdup(tmp);
 
-	while (*lp != '\0' && isspace(*lp))
+	while (*lp != '\0' && isspace((int) *lp))
 		lp++;
 
 	tp = tmp;
@@ -409,9 +408,9 @@ reg	char	*tp;
 	}
 	else
 		for (;;) {
-			while (*lp != '\0' && ! isspace(*lp))
+			while (*lp != '\0' && ! isspace((int) *lp))
 				*tp++ = *lp++;
-			while (*lp != '\0' && isspace(*lp))
+			while (*lp != '\0' && isspace((int) *lp))
 				lp++;
 			if (*lp == '\0')
 				break;
@@ -597,7 +596,7 @@ find_file(hbf, filename)
 	const char *filename;
 {
 	BM_FILE	**fp;
-reg	BM_FILE	*file;
+	BM_FILE	*file;
 	FILE	*f;
 	char *bmfname;
 #ifdef IN_MEMORY
@@ -635,7 +634,7 @@ reg	BM_FILE	*file;
 		if ((f = fopen(tmp, "r")) != NULL) {
 			fclose(f);
 			sprintf(tmp, "%s %s.gz", GUNZIP_CMD, file->bmf_name);
-			if ((f = popen(tmp, "r")) != NULL)
+                        if ((f = (FILE *) popen(tmp, "r")) != NULL)
 				from_pipe = TRUE;
 		}
 	}
@@ -756,9 +755,9 @@ skip_word(n, s)
 	const	char	*s;
 {
 	for ( ; n > 0; n--) {
-		while (*s != '\0' && ! isspace(*s))
+		while (*s != '\0' && ! isspace((int) *s))
 			s++;
-		while (*s != '\0' && isspace(*s))
+		while (*s != '\0' && isspace((int) *s))
 			s++;
 	}
 	return s;
@@ -867,7 +866,7 @@ get_line(buf, len, f)
 		}
 		if (c == '\n' || c == '\r') {
 			/* trim trailing space */
-			while (bp > buf && isspace(*(bp-1)))
+			while (bp > buf && isspace((int) *(bp-1)))
 				bp--;
 			*bp = '\0';
 			return TRUE;
