@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,12 +21,12 @@
  */
 
 /*
- * $Id: htext.h,v 1.28 1999/11/16 20:34:22 mleisher Exp $
+ * $Id: htext.h,v 1.30 2000/03/16 21:21:40 mleisher Exp $
  */
 static char *about_text = "\
-                 XmBDFEditor 4.3\n\
+                 XmBDFEditor 4.4\n\
               mleisher@crl.nmsu.edu\n\
-                       16 November 1999\n\
+                       16 March 2000\n\
 \n\
 XmBDFEditor is a BDF font editor that supports\n\
 these main features:\n\
@@ -89,6 +88,7 @@ The command line parameters for xmbdfed are:\n\
  -eol e  - set the default end of line char(s) (\"u\", \"d\", \"m\")\n\
  -g code - set the initial glyph code (decimal, hex, or octal)\n\
  -pb     - use watch cursor instead of progress bar\n\
+ -cb base- set the code base for glyph codes (\"oct\", \"dec\", \"hex\")\n\
 ";
 
 static char *fgrid_text = "\
@@ -472,20 +472,20 @@ Shift+PageDown\n\
   operation will be done that number of times.\n\
 \n\
 Shift+Home\n\
-  This will extend the selection to the first page that
+  This will extend the selection to the first page that\n\
   has glyphs.\n\
   If a decimal number is typed before this, this\n\
   operation will be done that number of times.\n\
 \n\
 Shift+End\n\
-  This will extend the selection to the last page that
+  This will extend the selection to the last page that\n\
   has glyphs.\n\
   If a decimal number is typed before this, this\n\
   operation will be done that number of times.\n\
 \n\
 Button1Down\n\
   This will start selecting glyphs.  If Button1 is\n\
-  double-clicked, it will edit the current glyph.
+  double-clicked, it will edit the current glyph.\n\
 \n\
 Button1Motion\n\
   This will extend the selected glyphs.\n\
@@ -862,6 +862,13 @@ are used:\n\
     If an unknown <font-spacing> value is\n\
     encountered, the default value is\n\
     \"proportional\".\n\
+\n\
+  <codebase>\n\
+    A <codebase> value can be one of \"octal\",\n\
+    \"decimal\", or \"hexadecimal\".  It can also\n\
+    be shortened to just the first letter.  Any\n\
+    unknown <codebase> values are assumed to be\n\
+    \"hexadecimal\".\n\
 \n\
   <translation>\n\
     A <translation> is a valid X Toolkit translation\n\
@@ -881,6 +888,11 @@ the configuration file:\n\
 \n\
   XmBDFEditor Configuration File Options\n\
   ======================================\n\
+    code_base <codebase> [default: \"hex\"]\n\
+\n\
+      By default, set the code base used to display the\n\
+      glyph encodings to base 16, or hex.  This option can\n\
+      be set to \"oct\", \"dec\", or \"hex\".\n\
 \n\
    skip_blank_pages <boolean> [default: \"true\"]\n\
 \n\
@@ -1044,8 +1056,8 @@ the configuration file:\n\
     NOTE: This is for use with the SBIT utility from\n\
     Microsoft.\n\
 \n\
-     This feature is toggled using the \"Setup->Other Options\"\n\
-     dialog.\n\
+    This feature is toggled using the \"Setup->Other Options\"\n\
+    dialog.\n\
 \n\
   General Font Configuration Options\n\
   ==================================\n\
