@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,9 +21,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: ops.c,v 1.3 1999/09/14 17:40:47 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: ops.c,v 1.4 2000/03/16 20:08:55 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: ops.c,v 1.3 1999/09/14 17:40:47 mleisher Exp $";
+static char rcsid[] = "$Id: ops.c,v 1.4 2000/03/16 20:08:55 mleisher Exp $";
 #endif
 #endif
 
@@ -691,7 +690,7 @@ void
 ShowEmboldenDialog(XtCallbackProc cback, XtPointer data,
                    Boolean toggles_sensitive)
 #else
-ShowEmoldenDialog(cback, data, toggles_sensitive)
+ShowEmboldenDialog(cback, data, toggles_sensitive)
 XtCallbackProc cback;
 XtPointer data;
 Boolean toggles_sensitive;
