@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -22,9 +21,9 @@
  */
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: setup.c,v 1.15 1999/10/23 13:43:37 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: setup.c,v 1.16 2000/03/16 20:08:55 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: setup.c,v 1.15 1999/10/23 13:43:37 mleisher Exp $";
+static char rcsid[] = "$Id: setup.c,v 1.16 2000/03/16 20:08:55 mleisher Exp $";
 #endif
 #endif
 
@@ -398,9 +397,10 @@ Widget w;
 XtPointer client_data, call_data;
 #endif
 {
-    if ((setup.bpp = (int) client_data) > 1)
-      XtSetSensitive(setup.colors, True);
-    else
+    if ((setup.bpp = (int) client_data) > 1) {
+        xmbdfedAllocateColors(top, (int) client_data);
+        XtSetSensitive(setup.colors, True);
+    } else
       XtSetSensitive(setup.colors, False);
     XtSetSensitive(setup.update, True);
 }
