@@ -1,6 +1,5 @@
 /*
- * Copyright 1996, 1997, 1998, 1999 Computing Research Labs,
- * New Mexico State University
+ * Copyright 2000 Computing Research Labs, New Mexico State University
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
  * copy of this software and associated documentation files (the "Software"),
@@ -28,9 +27,9 @@
 
 #ifndef lint
 #ifdef __GNUC__
-static char rcsid[] __attribute__ ((unused)) = "$Id: ttfin.c,v 1.3 1999/10/16 20:55:37 mleisher Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Id: ttfin.c,v 1.4 2000/03/16 20:08:56 mleisher Exp $";
 #else
-static char rcsid[] = "$Id: ttfin.c,v 1.3 1999/10/16 20:55:37 mleisher Exp $";
+static char rcsid[] = "$Id: ttfin.c,v 1.4 2000/03/16 20:08:56 mleisher Exp $";
 #endif
 #endif
 
@@ -199,7 +198,8 @@ XtPointer client_data, call_data;
             ErrorDialog(name);
             XtFree(fname);
             return;
-        }
+        } else
+          face_open = 1;
 
         /*
          * Get the properties for the face so it is current if the
@@ -432,7 +432,8 @@ bdf_font_t **font;
      * Initialize the FreeType engine once per session.
      */
     if (!ftinit) {
-        if (TT_Init_FreeType(&engine) != 0) {
+        if (TT_Init_FreeType(&engine) != 0 ||
+            TT_Init_SBit_Extension(engine) != 0) {
             ErrorDialog("Unable to initialize the FreeType engine.");
             return 0;
         }
